@@ -1,14 +1,8 @@
-/* ============================================================
- *
- * This file is part of the KDE project
- *
- * Description : Base class for option widgets
- *
+/*
  * SPDX-FileCopyrightText: 2011 Kare Sars <kare.sars@iki.fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef KSANE_OPTION_WIDGET_H
 #define KSANE_OPTION_WIDGET_H
@@ -18,6 +12,8 @@
 #include <QLabel>
 #include <QGridLayout>
 
+#include <KSaneCore/Option>
+
 namespace KSaneIface
 {
 
@@ -26,7 +22,7 @@ namespace KSaneIface
   */
 
 /**
- * A wrapper for a checkbox
+ * Base class for option widgets
  */
 class KSaneOptionWidget : public QWidget
 {
@@ -39,16 +35,24 @@ public:
      * \param labelText text.
      */
     KSaneOptionWidget(QWidget *parent, const QString &labelText);
-    ~KSaneOptionWidget();
+
+    KSaneOptionWidget(QWidget *parent, KSaneCore::Option *option);
+    ~KSaneOptionWidget() override;
 
     void setLabelText(const QString &text);
 
     int labelWidthHint();
     void setLabelWidth(int labelWidth);
 
+protected Q_SLOTS:
+    void updateVisibility();
+
 protected:
+    void initWidget();
+
     QLabel      *m_label;
     QGridLayout *m_layout;
+    KSaneCore::Option *m_option = nullptr;
 };
 
 }  // NameSpace KSaneIface
